import { LkrOptions } from './Contracts';
/**
 * A Fluent Storage API.
 */
declare class Lkr {
    /**
     * The configuration options.
     */
    private opts;
    /**
     * The Store instance.
     */
    private store;
    /**
     * Create a Lkr instance.
     */
    constructor(options: LkrOptions);
    /**
     * Get the options.
     */
    readonly options: LkrOptions;
    /**
     * Get the prefix.
     */
    private readonly prefix;
    /**
     * Get the fully qualified key.
     */
    private getKey(key);
    /**
     * Add a new item to storage even if it already exists.
     */
    put(key: any, val: any, def?: any): Lkr;
    /**
     * Add an item to storage if it doesn't already exist.
     */
    add(key: any, value: any, def?: any): boolean;
    /**
     * Retrieve the specified item from storage.
     */
    get(key: any, def?: any): any;
    /**
     * Determine whether the item exists in storage.
     */
    has(key: any): boolean;
    /**
     * Remove specified item(s) from storage.
     */
    forget(key: any): Lkr;
    /**
     * Retrieve the specified item from storage and then remove it
     */
    pull(key: any, def?: any): any;
    /**
     * Get all the items in storage within the currently set namespace/driver.
     */
    all(): object;
    /**
     * Iterate through the items within the current namespace/driver
     * and execute the callback.
     */
    each(callback: Function, thisContext?: object): void;
    /**
     * Get the storage keys as an array.
     */
    keys(): string[];
    /**
     * Remove all items set within the current namespace/driver.
     */
    clean(): Lkr;
    /**
     * Empty the current storage driver completely. Careful now.
     */
    empty(): Lkr;
    /**
     * Get the total number of items within the current namespace/driver.
     */
    count(): number;
    /**
     * Set the driver by key.
     */
    driver(driver: string): Lkr;
    /**
     * Set the namespace.
     */
    namespace(namespace: string): Lkr;
    /**
     * Create a new instance of Lkr.
     */
    static make(options: LkrOptions): Lkr;
}
export default Lkr;
