import { Serializer } from './Contracts';
/**
 * A decorator for a Storage implementation
 */
declare class Store {
    /**
     * The driver instance
     */
    private driver;
    /**
     * The Serializer instance
     */
    private serializer;
    /**
     * Create a Store instance.
     */
    constructor(driver: Storage, serializer?: Serializer);
    /**
     * Add a key/value pair to storage
     */
    setItem(key: string, val: any): Store;
    /**
     * Retrieve a value from storage by key
     */
    getItem(key: string): any;
    /**
     * Determine whether the key exists in storage.
     */
    hasItem(key: string): boolean;
    /**
     * Remove an item from storage.
     */
    removeItem(key: string): boolean;
    /**
     * Remove all items from storage.
     */
    clear(): Store;
    /**
     * Iterate through the items in storage and execute the callback.
     */
    forEach(callback: Function, thisContext?: object): void;
    /**
     * Determine whether the storage driver is supported.
     */
    isSupported(): boolean;
    /**
     * Get the number of items in storage.
     */
    readonly length: number;
}
export default Store;
